@@ -1,10 +1,5 @@
 var NAVTREEINDEX141 =
 {
-"servicecom_1_1sun_1_1star_1_1chart_1_1ChartArea.html#af8b545496add92e39f9d5d78886ab77b":[2,0,0,0,0,21,16,1],
-"servicecom_1_1sun_1_1star_1_1chart_1_1ChartArea.html#af8b545496add92e39f9d5d78886ab77b":[3,0,0,0,0,21,6,1],
-"servicecom_1_1sun_1_1star_1_1chart_1_1ChartArea.html#affe824eb78c13277161834e7fdff6cc9":[2,0,0,0,0,21,16,0],
-"servicecom_1_1sun_1_1star_1_1chart_1_1ChartArea.html#affe824eb78c13277161834e7fdff6cc9":[3,0,0,0,0,21,6,0],
-"servicecom_1_1sun_1_1star_1_1chart_1_1ChartAxis.html":[2,0,0,0,0,21,17],
 "servicecom_1_1sun_1_1star_1_1chart_1_1ChartAxis.html":[3,0,0,0,0,21,7],
 "servicecom_1_1sun_1_1star_1_1chart_1_1ChartAxis.html#a0f151153ffd69f5235a116a02c250850":[2,0,0,0,0,21,17,34],
 "servicecom_1_1sun_1_1star_1_1chart_1_1ChartAxis.html#a0f151153ffd69f5235a116a02c250850":[3,0,0,0,0,21,7,34],
@@ -249,5 +244,10 @@ var NAVTREEINDEX141 =
 "servicecom_1_1sun_1_1star_1_1chart_1_1ChartStatistics.html#aa1e6ca26ef5e437f0936941046e4a5bc":[2,0,0,0,0,21,34,10],
 "servicecom_1_1sun_1_1star_1_1chart_1_1ChartStatistics.html#aa1e6ca26ef5e437f0936941046e4a5bc":[3,0,0,0,0,21,24,10],
 "servicecom_1_1sun_1_1star_1_1chart_1_1ChartStatistics.html#aa87b6aea6bc76d552d3f578081c3e806":[2,0,0,0,0,21,34,3],
-"servicecom_1_1sun_1_1star_1_1chart_1_1ChartStatistics.html#aa87b6aea6bc76d552d3f578081c3e806":[3,0,0,0,0,21,24,3]
+"servicecom_1_1sun_1_1star_1_1chart_1_1ChartStatistics.html#aa87b6aea6bc76d552d3f578081c3e806":[3,0,0,0,0,21,24,3],
+"servicecom_1_1sun_1_1star_1_1chart_1_1ChartStatistics.html#aba7b668a0bff891197388e78d1af820f":[2,0,0,0,0,21,34,4],
+"servicecom_1_1sun_1_1star_1_1chart_1_1ChartStatistics.html#aba7b668a0bff891197388e78d1af820f":[3,0,0,0,0,21,24,4],
+"servicecom_1_1sun_1_1star_1_1chart_1_1ChartStatistics.html#ad63b1fe76644af84f03a126da46469ad":[2,0,0,0,0,21,34,7],
+"servicecom_1_1sun_1_1star_1_1chart_1_1ChartStatistics.html#ad63b1fe76644af84f03a126da46469ad":[3,0,0,0,0,21,24,7],
+"servicecom_1_1sun_1_1star_1_1chart_1_1ChartStatistics.html#ae6872c0d73362de7c3f167030e03e1cf":[2,0,0,0,0,21,34,0]
 };
