@@ -1,5 +1,5 @@
 var servicecom_1_1sun_1_1star_1_1chart2_1_1GridProperties =
 [
-    [ "LineProperties", "servicecom_1_1sun_1_1star_1_1chart2_1_1GridProperties.html#a360075bd97e5a4787d283a473b073005", null ],
+    [ "::com::sun::star::drawing::LineProperties", "servicecom_1_1sun_1_1star_1_1chart2_1_1GridProperties.html#a360075bd97e5a4787d283a473b073005", null ],
     [ "Show", "servicecom_1_1sun_1_1star_1_1chart2_1_1GridProperties.html#a39dcb2e507d4d565339bbf2892bd3a42", null ]
 ];
\ No newline at end of file
